@@ -269,8 +269,7 @@ class DebianGitRepository(PkgGitRepository):
     @staticmethod
     def _sanitize_version(version):
         """sanitize a version so git accepts it as a tag
-
-        as described in DEP14
+        as described in DEP-14
 
         >>> DebianGitRepository._sanitize_version("0.0.0")
         '0.0.0'
@@ -291,8 +290,7 @@ class DebianGitRepository(PkgGitRepository):
     @staticmethod
     def _unsanitize_version(tag):
         """Reverse _sanitize_version
-
-        as described in DEP14
+        as described in DEP-14
 
         >>> DebianGitRepository._unsanitize_version("1%0_bpo3")
         '1:0~bpo3'
