@@ -39,16 +39,23 @@ class UpstreamSource(object):
     @cvar _unpacked: path to the unpacked source tree
     @type _unpacked: string
     """
-    def __init__(self, name, unpacked=None, pkg_policy=PkgPolicy):
+    def __init__(self, name, unpacked=None, pkg_policy=PkgPolicy, sig=None):
         self._orig = False
         self._pkg_policy = pkg_policy
         self._path = name
         self.unpacked = unpacked
+        self._sig = sig
 
         self._check_orig()
         if self.is_dir():
             self.unpacked = self.path
 
+    def __repr__(self):
+        path = "'%s'" % self.path if self.path is not None else None
+        sig = "'%s'" % self.signaturefile if self.signaturefile is not None else None
+        return "<%s path=%s signaturefile=%s>" % (self.__class__.__name__,
+                                                  path, sig)
+
     def _check_orig(self):
         """
         Check if upstream source format can be used as orig tarball.
@@ -93,6 +100,14 @@ class UpstreamSource(object):
     def path(self):
         return self._path.rstrip('/')
 
+    @property
+    def signaturefile(self):
+        return self._sig
+
+    @signaturefile.setter
+    def signaturefile(self, sig):
+        self._sig = sig
+
     def unpack(self, dir, filters=None):
         """
         Unpack packed upstream sources into a given directory
