@@ -19,7 +19,7 @@ class TestGitRepositoryCommitDir(DebianGitTestRepo):
                              'new content',
                              'master',
                              create_missing_branch=True)
-        self.assertEquals(self.repo.show('master:file1'), b'content1')
+        self.assertEqual(self.repo.show('master:file1'), b'content1')
 
     def test_long_reflog(self):
         """Make sure we fail on onverly long msg resulting in an
@@ -36,7 +36,7 @@ class TestGitRepositoryCommitDir(DebianGitTestRepo):
                              'foo\n' * 100000,
                              'master',
                              create_missing_branch=True)
-        self.assertEquals(self.repo.show('master:file1'), b'content1')
+        self.assertEqual(self.repo.show('master:file1'), b'content1')
         out, dummy, ret = self.repo._git_inout('reflog', [])
-        self.assertEquals(ret, 0)
+        self.assertEqual(ret, 0)
         self.assertIn(b'HEAD@{0}: gbp: foo\n', out)
